from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import String, Int, Boolean, Float, File

Sumtrees_Py_V0_1_0 = CommandToolBuilder(tool="sumtrees.py", base_command=["sumtrees.py"], inputs=[ToolInput(tag="in_source_format", input_type=String(optional=True), prefix="--source-format", doc=InputDocumentation(doc="Format of all input trees (defaults to handling either\nNEXUS or NEWICK through inspection; it is more\nefficient to explicitly specify the format if it is\nknown).")), ToolInput(tag="in_burnin", input_type=Int(optional=True), prefix="--burnin", doc=InputDocumentation(doc="Number of trees to skip from the beginning of *each*\ntree file when counting support (default: 0).")), ToolInput(tag="in_force_rooted", input_type=Boolean(optional=True), prefix="--force-rooted", doc=InputDocumentation(doc="Treat source trees as rooted.")), ToolInput(tag="in_force_unrooted", input_type=Boolean(optional=True), prefix="--force-unrooted", doc=InputDocumentation(doc="Treat source trees as unrooted.")), ToolInput(tag="in_weighted_trees", input_type=Boolean(optional=True), prefix="--weighted-trees", doc=InputDocumentation(doc="Use weights of trees (as indicated by '[&W m/n]'\ncomment token) to weight contribution of splits found\non each tree to overall split frequencies.")), ToolInput(tag="in_preserve_underscores", input_type=Boolean(optional=True), prefix="--preserve-underscores", doc=InputDocumentation(doc="Do not convert unprotected (unquoted) underscores to\nspaces when reading NEXUS/NEWICK format trees.")), ToolInput(tag="in_ultrametric_ity_precision", input_type=Float(optional=True), prefix="--ultrametricity-precision", doc=InputDocumentation(doc="Precision to use when validating ultrametricity\n(default: 1e-05; specify '0' to disable validation).")), ToolInput(tag="in_tax_on_names_file_path", input_type=File(optional=True), prefix="--taxon-names-filepath", doc=InputDocumentation(doc="Path to file listing all the taxon names or labels\nthat will be found across the entire set of source\ntrees. This file should be a plain text file with a\nsingle name list on each line. This file is only read\nwhen multiprocessing ('-M' or '-m') is requested. When\nmultiprocessing using the '-M' or '-m' options, all\ntaxon names need to be defined in advance of any\nactual tree analysis. By default this is done by\nreading the first tree in the first tree source and\nextracting the taxon names. At best, this is,\ninefficient, as it involves an extraneous reading of\nthe tree. At worst, this can be errorneous, if the\nfirst tree does not contain all the taxa. Explicitly\nproviding the taxon names via this option can avoid\nthese issues.")), ToolInput(tag="in_tip_ages_file_path", input_type=File(optional=True), prefix="--tip-ages-filepath", doc=InputDocumentation(doc="Path to file providing ages (i.e., time from present)\nof tips. For format of this file, see '--tip-age-\nformat'. If not specified, or for any taxon omitted\nfrom the data, an age of 0.0 will be assumed.")), ToolInput(tag="in_tip_ages_format", input_type=File(optional=True), prefix="--tip-ages-format", doc=InputDocumentation(doc="Format of the tip date data (default: 'tsv'):\n- 'tsv'\nA tab-delimited file. This should consist of two\ncolumns separated by tabs. The first column\nlists the taxon labels (matching the taxon label\nof the input trees EXACTLY) and the second\ncolumn lists the ages of the corresponding tips.\n- 'csv'\nA comma-delimited file. This should consist of\ntwo columns separated by commas. The first\ncolumn lists the taxon labels (matching the\ntaxon label of the input trees EXACTLY) and the\nsecond column lists the ages of the\ncorresponding tips.\n- 'json'\nA JSON file. This should specify a single\ndictionary at the top-level with keys being\ntaxon labels (matching the taxon labels of the\ninput trees EXACTLY) and values being the ages\nof the corresponding tips.")), ToolInput(tag="in_no_trim_tip_age_labels", input_type=Boolean(optional=True), prefix="--no-trim-tip-age-labels", doc=InputDocumentation(doc="By default, whitespace will be trimmed from the labels\nfound in the tip ages data source. Specifing this\noption suppresses this.")), ToolInput(tag="in_target_tree_file_path", input_type=File(optional=True), prefix="--target-tree-filepath", doc=InputDocumentation(doc="Summarize support and other information from the\nsource trees to topology or topologies given by the\ntree(s) described in FILE. If no use-specified target\ntopologies are given, then a summary topology will be\nused as the target. Use the '-s' or '--summary-target'\nto specify the type of summary tree to use.")), ToolInput(tag="in_summary_target", input_type=Int(optional=True), prefix="--summary-target", doc=InputDocumentation(doc="Construct and summarize support and other information\nfrom the source trees to one of the following summary\ntopologies:\n- 'consensus'\nA consensus tree. The minimum frequency\nthreshold of clades to be included can be\nspecified using the '-f' or '--min-clade-freq'\nflags. This is the DEFAULT if a user- specified\ntarget tree is not given through the '-t' or '--\ntarget-tree-filepath' options.\n- 'mcct'\nThe maximum clade credibility tree. The tree\nfrom the source set that maximizes the *product*\nof clade posterior probabilities.\n- 'msct'\nThe maximum sum of clade credibilities tree. The\ntree from the source set that maximizes the\n*sum* of clade posterior probabilities.")), ToolInput(tag="in__mincladefreq_", input_type=Boolean(optional=True), prefix="-f", doc=InputDocumentation(doc="#.##, --min-clade-freq #.##, --min-freq #.##, --min-split-freq #.##, --min-consensus-freq #.##\nMinimum frequency or probability for a clade or a\nsplit to be included in the summary target trees. If\nuser-defined or non-consensus trees are specified as\nsummary targets and a explicit value is provided for\nthis argument, then clades with support values below\nthis threshold will be collapsed. If a consensus tree\nsummary target is specified, then clades with support\nvalues below this threshold will not be included, and\nthis threshold takes on a default value of greater\nthan 0.5 if not explicitly specified.")), ToolInput(tag="in_allow_unknown_target_tree_tax_a", input_type=Boolean(optional=True), prefix="--allow-unknown-target-tree-taxa", doc=InputDocumentation(doc="Do not fail with error if target tree(s) have taxa not\npreviously encountered in source trees or defined in\nthe taxon discovery file.")), ToolInput(tag="in_root_target_at_out_group", input_type=String(optional=True), prefix="--root-target-at-outgroup", doc=InputDocumentation(doc="Root target tree(s) using specified taxon as outgroup.")), ToolInput(tag="in_root_target_at_midpoint", input_type=Boolean(optional=True), prefix="--root-target-at-midpoint", doc=InputDocumentation(doc="Root target tree(s) at midpoint.")), ToolInput(tag="in_set_out_group", input_type=String(optional=True), prefix="--set-outgroup", doc=InputDocumentation(doc="Rotate the target trees such the specified taxon is in\nthe outgroup position, but do not explicitly change\nthe target tree rooting.")), ToolInput(tag="in_set_edges", input_type=Int(optional=True), prefix="--set-edges", doc=InputDocumentation(doc="Set the edge lengths of the target or summary trees\nbased on the specified summarization STRATEGY:\n- 'mean-length'\nEdge lengths will be set to the mean of the\nlengths of the corresponding split or clade in\nthe source trees.\n- 'median-length'\nEdge lengths will be set to the median of the\nlengths of the corresponding split or clade in\nthe source trees.\n- 'mean-age'\nEdge lengths will be adjusted so that the age of\nsubtended nodes will be equal to the mean age of\nthe corresponding split or clade in the source\ntrees. Source trees will need to to be\nultrametric for this option.\n- 'median-age'\nEdge lengths will be adjusted so that the age of\nsubtended nodes will be equal to the median age\nof the corresponding split or clade in the\nsource trees. Source trees will need to to be\nultrametric for this option.\n- support\nEdge lengths will be set to the support value\nfor the split represented by the edge.\n- 'keep'\nDo not change the existing edge lengths. This is\nthe DEFAULT if target tree(s) are sourced from\nan external file using the '-t' or '--target-\ntree-filepath' option\n- 'clear'\nEdge lengths will be cleared from the target\ntrees if they are present.\nNote the default settings varies according to the\nfollowing, in order of preference:\n(1) If target trees are specified using the '-t' or\n'--target-tree-filepath' option, then the default edge\nsummarization strategy is: 'keep'.\n(2) If target trees are not specified, but the\n'--summarize-node-ages' option is specified,\nthen the default edge summarization strategy is:\n'mean-age'.\n(3) If no target trees are specified and the\nnode ages are NOT specified to be summarized,\nthen the default edge summarization strategy is:\n'mean-length'.")), ToolInput(tag="in_force_minimum_edge_length", input_type=Int(optional=True), prefix="--force-minimum-edge-length", doc=InputDocumentation(doc="(If setting edge lengths) force all edges to be at\nleast this length.")), ToolInput(tag="in_collapse_negative_edges", input_type=Boolean(optional=True), prefix="--collapse-negative-edges", doc=InputDocumentation(doc="(If setting edge lengths) force parent node ages to be\nat least as old as its oldest child when summarizing\nnode ages.")), ToolInput(tag="in_summarize_node_ages", input_type=Boolean(optional=True), prefix="--summarize-node-ages", doc=InputDocumentation(doc="Assume that source trees are ultrametic and summarize\nnode ages (distances from tips).")), ToolInput(tag="in_labels", input_type=String(optional=True), prefix="--labels", doc=InputDocumentation(doc="Set the node labels of the summary or target tree(s):\n- 'support'\nNode labels will be set to the support value for\nthe clade represented by the node. This is the\nDEFAULT.\n- 'keep'\nDo not change the existing node labels.\n- 'clear'\nNode labels will be cleared from the target\ntrees if they are present.")), ToolInput(tag="in_suppress_annotations", input_type=Boolean(optional=True), prefix="--suppress-annotations", doc=InputDocumentation(doc="Do NOT annotate nodes and edges with any summarization\ninformation metadata such as.support values, edge\nlength and/or node age summary statistcs, etc.")), ToolInput(tag="in_percentages", input_type=Boolean(optional=True), prefix="--percentages", doc=InputDocumentation(doc="Indicate branch support as percentages (otherwise,\nwill report as proportions by default).")), ToolInput(tag="in_decimals_number_decimal", input_type=Boolean(optional=True), prefix="-d", doc=InputDocumentation(doc="#, --decimals #    Number of decimal places in indication of support\nvalues (default: 8).")), ToolInput(tag="in_output_tree_file_path", input_type=File(optional=True), prefix="--output-tree-filepath", doc=InputDocumentation(doc="Path to output file (if not specified, will print to\nstandard output).")), ToolInput(tag="in_output_tree_format", input_type=String(optional=True), prefix="--output-tree-format", doc=InputDocumentation(doc="Format of the output tree file (if not specifed,\ndefaults to input format, if this has been explicitly\nspecified, or 'nexus' otherwise).")), ToolInput(tag="in_extended_output", input_type=String(optional=True), prefix="--extended-output", doc=InputDocumentation(doc="If specified, extended summarization information will\nbe generated, consisting of the following files:\n- '<PREFIX>.topologies.trees'\nA collection of topologies found in the sources\nreported with their associated posterior\nprobabilities as metadata annotations.\n- '<PREFIX>.bipartitions.trees'\nA collection of bipartitions, each represented\nas a tree, with associated information as\nmetadataannotations.\n- '<PREFIX>.bipartitions.tsv'\nTable listing bipartitions as a group pattern as\nthe key column, and information regarding each\nthe bipartitions as the remaining columns.\n- '<PREFIX>.edge-lengths.tsv'\nList of bipartitions and corresponding edge\nlengths. Only generated if edge lengths are\nsummarized.\n- '<PREFIX>.node-ages.tsv'\nList of bipartitions and corresponding ages.\nOnly generated if node ages are summarized.")), ToolInput(tag="in_no_tax_a_block", input_type=Boolean(optional=True), prefix="--no-taxa-block", doc=InputDocumentation(doc="When writing NEXUS format output, do not include a\ntaxa block in the output treefile (otherwise will\ncreate taxa block by default).")), ToolInput(tag="in_no_analysis_metainformation", input_type=Boolean(optional=True), prefix="--no-analysis-metainformation", doc=InputDocumentation(doc="Do not include meta-information describing the\nsummarization parameters and execution details.")), ToolInput(tag="in_additional_comments", input_type=File(optional=True), prefix="--additional-comments", doc=InputDocumentation(doc="Additional comments to be added to the summary file.")), ToolInput(tag="in_replace", input_type=File(optional=True), prefix="--replace", doc=InputDocumentation(doc="Replace/overwrite output file without asking if it\nalready exists.")), ToolInput(tag="in_maximum_multiprocessing", input_type=Boolean(optional=True), prefix="--maximum-multiprocessing", doc=InputDocumentation(doc="Run in parallel mode using as many processors as\navailable, up to the number of sources.")), ToolInput(tag="in_multiprocessing", input_type=Int(optional=True), prefix="--multiprocessing", doc=InputDocumentation(doc="Run in parallel mode with up to a maximum of NUM-\nPROCESSES processes ('max' or '#' means to run in as\nmany processes as there are cores on the local\nmachine; i.e., same as specifying '-M' or '--maximum-\nmultiprocessing').")), ToolInput(tag="in_log_frequency", input_type=Int(optional=True), prefix="--log-frequency", doc=InputDocumentation(doc="Tree processing progress logging frequency (default:\n500; set to 0 to suppress).")), ToolInput(tag="in_quiet", input_type=Boolean(optional=True), prefix="--quiet", doc=InputDocumentation(doc="Suppress ALL logging, progress and feedback messages.")), ToolInput(tag="in_ignore_missing_support", input_type=Boolean(optional=True), prefix="--ignore-missing-support", doc=InputDocumentation(doc="Ignore missing support tree files (note that at least\none must exist).")), ToolInput(tag="in_usage_examples", input_type=Boolean(optional=True), prefix="--usage-examples", doc=InputDocumentation(doc="Show usage examples of program and exit.")), ToolInput(tag="in_describe", input_type=Boolean(optional=True), prefix="--describe", doc=InputDocumentation(doc="Show information regarding your DendroPy and Python\ninstallations and exit.\n")), ToolInput(tag="in_tree_file_path", input_type=File(), position=0, doc=InputDocumentation(doc="Source(s) of trees to summarize. At least one valid\nsource of trees must be provided. Use '-' to specify\nreading from standard input (note that this requires\nthe input file format to be explicitly set using the '\n--source-format' option)."))], outputs=[ToolOutput(tag="out_output_tree_file_path", output_type=File(optional=True), selector=InputSelector(input_to_select="in_output_tree_file_path", type_hint=File()), doc=OutputDocumentation(doc="Path to output file (if not specified, will print to\nstandard output).")), ToolOutput(tag="out_replace", output_type=File(optional=True), selector=InputSelector(input_to_select="in_replace", type_hint=File()), doc=OutputDocumentation(doc="Replace/overwrite output file without asking if it\nalready exists."))], container="quay.io/biocontainers/dendropy:4.5.2--pyh3252c3a_0", version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Sumtrees_Py_V0_1_0().translate("wdl")

